@@ -9,13 +9,11 @@ test_that("fails well with no input", {
 test_that("fails well with non-existent page", {
 	skip_on_cran()
 
-  expect_error(topic("asfafsfadfasdfd"),
-               "404 - Oops! That page doesn’t exist or is private.")
+  expect_error(topic("asfafsfadfasdfd"), "404")
 })
 
-test_that("httr curl options work", {
+test_that("curl options work", {
 	skip_on_cran()
 
-  library("httr")
-  expect_error(topic("asdfadf", config = timeout(seconds = 0.001)))
+  expect_error(topic("asdfadf", timeout_ms = 1))
 })
